pub enum SMPR {
_0,
_1,
}Expand description
Possible values of the field SMP
Variants
_0
Just one sample is used to determine the bit value.
_1
Three samples are used to determine the value of the received bit: the regular one (sample point) and 2 preceding samples; a majority rule is used.
Implementations
Sourceimpl SMPR
impl SMPR
Sourcepub fn bit_is_clear(&self) -> bool
pub fn bit_is_clear(&self) -> bool
Returns true if the bit is clear (0)
Sourcepub fn bit_is_set(&self) -> bool
pub fn bit_is_set(&self) -> bool
Returns true if the bit is set (1)