pub enum SWOCW {
_0,
_1,
}Expand description
Values that can be written to the field SWOC
Variants
_0
SWOCTRL register is updated with its buffer value at all rising edges of system clock.
_1
SWOCTRL register is updated with its buffer value by the PWM synchronization.