pub enum LOOPSW {
_0,
_1,
}Expand description
Values that can be written to the field LOOPS
Variants
_0
Normal operation.
_1
Loop mode where transmitter output is internally connected to receiver input. The receiver input is determined by the RSRC bit.