pub enum TDMASR {
_0,
_1,
}Expand description
Possible values of the field TDMAS
Variants
_0
If C2[TIE] is set and the S1[TDRE] flag is set, the TDRE interrupt request signal is asserted to request interrupt service.
_1
If C2[TIE] is set and the S1[TDRE] flag is set, the TDRE DMA request signal is asserted to request a DMA transfer.
Implementations
Sourceimpl TDMASR
impl TDMASR
Sourcepub fn bit_is_clear(&self) -> bool
pub fn bit_is_clear(&self) -> bool
Returns true if the bit is clear (0)
Sourcepub fn bit_is_set(&self) -> bool
pub fn bit_is_set(&self) -> bool
Returns true if the bit is set (1)