pub enum RWUIDR {
_0,
_1,
}Expand description
Possible values of the field RWUID
Variants
_0
The S1[IDLE] bit is not set upon detection of an idle character.
_1
The S1[IDLE] bit is set upon detection of an idle character.
Implementations
Sourceimpl RWUIDR
impl RWUIDR
Sourcepub fn bit_is_clear(&self) -> bool
pub fn bit_is_clear(&self) -> bool
Returns true if the bit is clear (0)
Sourcepub fn bit_is_set(&self) -> bool
pub fn bit_is_set(&self) -> bool
Returns true if the bit is set (1)