pub enum RWUIDW {
_0,
_1,
}Expand description
Values that can be written to the field RWUID
Variants
_0
The S1[IDLE] bit is not set upon detection of an idle character.
_1
The S1[IDLE] bit is set upon detection of an idle character.