pub enum RXRTSEW {
_0,
_1,
}Expand description
Values that can be written to the field RXRTSE
Variants
_0
The receiver has no effect on RTS.
_1
RTS is deasserted if the number of characters in the receiver data register (FIFO) is equal to or greater than RWFIFO[RXWATER]. RTS is asserted when the number of characters in the receiver data register (FIFO) is less than RWFIFO[RXWATER].