pub enum RWUR {
_0,
_1,
}Expand description
Possible values of the field RWU
Variants
_0
Normal operation.
_1
RWU enables the wakeup function and inhibits further receiver interrupt requests. Normally, hardware wakes the receiver by automatically clearing RWU.
Implementations
Sourceimpl RWUR
impl RWUR
Sourcepub fn bit_is_clear(&self) -> bool
pub fn bit_is_clear(&self) -> bool
Returns true if the bit is clear (0)
Sourcepub fn bit_is_set(&self) -> bool
pub fn bit_is_set(&self) -> bool
Returns true if the bit is set (1)